@@ -1,4 +1,4 @@
-/* $Id: gweather-dialog.c,v 1.35 2004/02/23 00:24:55 dsmit Exp $ */
+/* $Id: gweather-dialog.c,v 1.36 2004/05/14 01:31:04 davyd Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -285,6 +285,8 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
 				  GTK_POLICY_AUTOMATIC,
 				  GTK_POLICY_AUTOMATIC);
+  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled_window),
+		  		       GTK_SHADOW_ETCHED_IN);
 
   gw_applet->forecast_text = gtk_text_view_new ();
   set_access_namedesc (gw_applet->forecast_text, _("Forecast Report"),                                                             _("See the ForeCast Details"));
