@@ -238,7 +238,7 @@ gstreamer_normalize_volume (GstMixerTrack *track,
 	t = (vol - track->min_volume) /
 		(double) (track->max_volume - track->min_volume);
 
-	return (gint) (VOLUME_MAX * t);
+	return (gint) (VOLUME_MAX * t + 0.5);
 }
 
 /*
@@ -255,7 +255,7 @@ gstreamer_trackify_volume (GstMixerTrack *track,
 
 	t = vol / (double) VOLUME_MAX;
 	
-	return (gint) (t * (track->max_volume - track->min_volume)
+	return (gint) (t * (track->max_volume - track->min_volume) + 0.5
 		       + track->min_volume);
 }
 
@@ -1238,11 +1238,11 @@ destroy_mixer_cb (GtkWidget *widget, MixerData *data)
 }
 
 static void
-applet_change_background_cb (PanelApplet               *applet,
-			     PanelAppletBackgroundType  type,
-			     GdkColor                  *color,
-			     const gchar               *pixmap,
-			     MixerData                 *data)
+applet_change_background_cb (PanelApplet		*applet,
+			     PanelAppletBackgroundType	type,
+			     GdkColor			*color,
+			     GdkPixmap			*pixmap,
+			     MixerData			*data)
 {
 	if (type == PANEL_NO_BACKGROUND) {
 		GtkRcStyle *rc_style = gtk_rc_style_new ();
@@ -1284,8 +1284,11 @@ mixer_start_gmix_cb (BonoboUIComponent *uic,
 	if (!run_mixer_cmd)
 		return;
 
-	egg_screen_execute_command_line_async (
-			gtk_widget_get_screen (data->applet), run_mixer_cmd, &error);
+	gdk_spawn_command_line_on_screen (
+			gtk_widget_get_screen (GTK_WIDGET (data->applet)),
+			run_mixer_cmd,
+			&error);
+
 	if (error) {
 		GtkWidget *dialog;
 
@@ -1329,6 +1332,9 @@ mixer_about_cb (BonoboUIComponent *uic,
 	const gchar *translator_credits = _("translator_credits");
 	
         if (data->about_dialog) {
+		gtk_window_set_screen (GTK_WINDOW (data->about_dialog),
+				       gtk_widget_get_screen (data->applet));
+
                 gtk_window_present (GTK_WINDOW (data->about_dialog));
                 return;
         }
@@ -1346,11 +1352,15 @@ mixer_about_cb (BonoboUIComponent *uic,
                                               pixbuf);
 
 	g_object_unref (pixbuf);
+	
 	gtk_window_set_screen (GTK_WINDOW (data->about_dialog),
 			       gtk_widget_get_screen (data->applet));
+
 	gtk_window_set_wmclass (GTK_WINDOW(data->about_dialog), "volume control", "Volume Control");
+
 	gnome_window_icon_set_from_file (GTK_WINDOW (data->about_dialog), GNOME_ICONDIR"/mixer/gnome-mixer-applet.png");
-        g_signal_connect (G_OBJECT (data->about_dialog), "destroy",
+        
+	g_signal_connect (G_OBJECT (data->about_dialog), "destroy",
                           G_CALLBACK (gtk_widget_destroyed),
 	                  &data->about_dialog);
 	
@@ -1643,16 +1653,13 @@ mixer_ui_component_event (BonoboUIComponent            *comp,
 
 static void
 get_channel (MixerData *data)
-{	
-#ifdef OSS_API
+{
 	PanelApplet *applet = PANEL_APPLET (data->applet);
-	gint num;
-	
-	num = panel_applet_gconf_get_int (applet, "channel", NULL);
-	num = CLAMP (num, 0,  SOUND_MIXER_NRDEVICES-1);	
-	data->mixerchannel = num;
-#endif
+	int num;
 
+	num = panel_applet_gconf_get_int (applet, "channel", NULL);
+	num = CLAMP (num, 0, g_list_length (data->channels) - 1);
+	data->mixerchannel = num;
 }
 
 static void
